@@ -2,11 +2,14 @@
 
 ;;; Code:
 
+(autoload 'custom-add-loads "cus-load")
+
 (custom-add-loads 'gnus-start '("gnus-group" "gnus-int" "gnus-start" "gnus-util" "gnus"))
 (custom-add-loads 'gnus-exit '("gnus-group" "gnus"))
 (custom-add-loads 'message '("message"))
 (custom-add-loads 'gnus-score-expire '("gnus-kill" "gnus-score"))
 (custom-add-loads 'gnus-score-kill '("gnus-kill" "gnus"))
+(custom-add-loads 'mime '("mm-bodies"))
 (custom-add-loads 'gnus-message '("message" "gnus"))
 (custom-add-loads 'gnus-summary-sort '("gnus-sum"))
 (custom-add-loads 'nnmail-procmail '("nnmail"))
@@ -21,7 +24,7 @@
 (custom-add-loads 'gnus-group-foreign '("gnus-group"))
 (custom-add-loads 'gnus-undo '("gnus-undo"))
 (custom-add-loads 'gnus-article-washing '("gnus-xmas" "gnus-art"))
-(custom-add-loads 'mail '("gnus" "message"))
+(custom-add-loads 'mail '("gnus" "message" "mm-decode"))
 (custom-add-loads 'gnus-summary-exit '("gnus-sum" "gnus"))
 (custom-add-loads 'gnus-article-saving '("gnus-art" "gnus"))
 (custom-add-loads 'gnus-extract-view '("gnus-sum" "gnus-uu"))
@@ -39,8 +42,10 @@
 (custom-add-loads 'gnus-nocem '("gnus-nocem"))
 (custom-add-loads 'gnus-threading '("gnus-sum"))
 (custom-add-loads 'gnus-summary-maneuvering '("gnus-sum"))
+(custom-add-loads 'gnus-charset '("gnus-group" "gnus-msg" "gnus-sum" "gnus"))
 (custom-add-loads 'gnus-extract '("gnus" "gnus-uu"))
 (custom-add-loads 'gnus-summary-tree '("gnus-salt"))
+(custom-add-loads 'mime-display '("mm-decode"))
 (custom-add-loads 'nnmail-split '("nnmail"))
 (custom-add-loads 'gnus-dribble-file '("gnus-start"))
 (custom-add-loads 'gnus-article-various '("gnus-art" "gnus-sum"))
@@ -48,10 +53,10 @@
 (custom-add-loads 'message-sending '("message"))
 (custom-add-loads 'gnus-article '("gnus-art" "gnus-cite"))
 (custom-add-loads 'gnus-agent '("gnus-agent"))
-(custom-add-loads 'gnus '("gnus-art" "gnus" "gnus-demon" "gnus-dup" "gnus-eform" "gnus-undo" "gnus-uu" "gnus-win" "gnus-xmas" "nnmail"))
+(custom-add-loads 'gnus '("gnus-art" "gnus-async" "gnus-demon" "gnus-dup" "gnus-eform" "gnus-undo" "gnus-uu" "gnus-win" "gnus-xmas" "gnus" "mail-source" "nnmail" "rfc1843"))
 (custom-add-loads 'gnus-xmas '("gnus-xmas"))
-(custom-add-loads 'gnus-treading '("gnus-sum"))
 (custom-add-loads 'nnmail '("nnmail"))
+(custom-add-loads 'mail-source '("mail-source"))
 (custom-add-loads 'gnus-article-hiding '("gnus-art" "gnus-sum"))
 (custom-add-loads 'nnmail-duplicate '("nnmail"))
 (custom-add-loads 'gnus-summary-visual '("gnus-sum" "gnus"))
@@ -63,9 +68,8 @@
 (custom-add-loads 'gnus-duplicate '("gnus-dup"))
 (custom-add-loads 'gnus-score-adapt '("gnus-score" "gnus"))
 (custom-add-loads 'nnmail-various '("nnmail"))
-(custom-add-loads 'gnus-group-level '("gnus"))
 (custom-add-loads 'nnmail-files '("nnmail"))
-(custom-add-loads 'gnus-asynchronous '("gnus" "gnus-async"))
+(custom-add-loads 'gnus-asynchronous '("gnus-async"))
 (custom-add-loads 'gnus-group-visual '("gnus-group" "gnus"))
 (custom-add-loads 'gnus-visual '("earcon" "gnus-art" "gnus-picon" "gnus" "smiley"))
 (custom-add-loads 'message-forwarding '("message"))
@@ -86,10 +90,11 @@
 (custom-add-loads 'gnus-extract-post '("gnus-uu"))
 (custom-add-loads 'faces '("gnus" "message"))
 (custom-add-loads 'gnus-various '("gnus-sum" "gnus"))
+(custom-add-loads 'gnus-group-icons '("gnus-group"))
 (custom-add-loads 'smiley '("smiley"))
 (custom-add-loads 'gnus-start-server '("gnus-start"))
-(custom-add-loads 'gnus-article-highlight '("gnus-art" "gnus"))
-(custom-add-loads 'news '("gnus" "message"))
+(custom-add-loads 'gnus-article-highlight '("gnus-art"))
+(custom-add-loads 'news '("gnus" "message" "mm-decode"))
 (custom-add-loads 'gnus-cache '("gnus-cache" "gnus"))
 (custom-add-loads 'message-insertion '("message"))
 (custom-add-loads 'message-faces '("message"))
@@ -98,6 +103,6 @@
 (custom-add-loads 'picons '("gnus-picon"))
 (custom-add-loads 'nnmail-prepare '("nnmail"))
 (custom-add-loads 'message-buffers '("message"))
-(custom-add-loads 'gnus-article-mime '("gnus-art" "gnus-sum"))
+(custom-add-loads 'gnus-article-mime '("gnus-art" "mm-uu"))
 
 ;;; custom-load.el ends here
