@@ -1,5 +1,6 @@
 ;;; gnus-ems.el --- functions for making Gnus work under different Emacsen
-;; Copyright (C) 1995,96,97,98 Free Software Foundation, Inc.
+;; Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000
+;;        Free Software Foundation, Inc.
 
 ;; Author: Lars Magne Ingebrigtsen <larsi@gnus.org>
 ;; Keywords: news
@@ -29,11 +30,14 @@
 
 ;;; Function aliases later to be redefined for XEmacs usage.
 
-(defvar gnus-xemacs (string-match "XEmacs\\|Lucid" emacs-version)
-  "Non-nil if running under XEmacs.")
+(eval-and-compile
+  (defvar gnus-xemacs (string-match "XEmacs" emacs-version)
+    "Non-nil if running under XEmacs."))
 
 (defvar gnus-mouse-2 [mouse-2])
+(defvar gnus-down-mouse-3 [down-mouse-3])
 (defvar gnus-down-mouse-2 [down-mouse-2])
+(defvar gnus-widget-button-keymap nil)
 (defvar gnus-mode-line-modified
   (if (or gnus-xemacs
 	  (< emacs-major-version 20))
@@ -45,72 +49,21 @@
   (autoload 'gnus-xmas-redefine "gnus-xmas")
   (autoload 'appt-select-lowest-window "appt"))
 
-(or (fboundp 'mail-file-babyl-p)
-    (fset 'mail-file-babyl-p 'rmail-file-p))
-
 ;;; Mule functions.
 
-(defun gnus-mule-cite-add-face (number prefix face)
-  ;; At line NUMBER, ignore PREFIX and add FACE to the rest of the line.
-  (when face
-    (let ((inhibit-point-motion-hooks t)
-	  from to)
-      (goto-line number)
-      (unless (eobp)            ; Sometimes things become confused (broken).
-        (if (boundp 'MULE)
-            (forward-char (chars-in-string prefix))
-          (forward-char (length prefix)))
-        (skip-chars-forward " \t")
-        (setq from (point))
-        (end-of-line 1)
-        (skip-chars-backward " \t")
-        (setq to (point))
-        (when (< from to)
-          (push (setq overlay (gnus-make-overlay from to))
-                gnus-cite-overlay-list)
-          (gnus-overlay-put (gnus-make-overlay from to) 'face face))))))
-
 (defun gnus-mule-max-width-function (el max-width)
-  (` (let* ((val (eval (, el)))
-	    (valstr (if (numberp val)
-			(int-to-string val) val)))
-       (if (> (length valstr) (, max-width))
-	   (truncate-string valstr (, max-width))
-	 valstr))))
-
-(defun gnus-encode-coding-string (string system)
-  string)
-
-(defun gnus-decode-coding-string (string system)
-  string)
+  `(let* ((val (eval (, el)))
+	  (valstr (if (numberp val)
+		      (int-to-string val) val)))
+     (if (> (length valstr) ,max-width)
+	 (truncate-string-to-width valstr ,max-width)
+       valstr)))
 
 (eval-and-compile
-  (if (string-match "XEmacs\\|Lucid" emacs-version)
-      nil
-
+  (if gnus-xemacs
+      (gnus-xmas-define)
     (defvar gnus-mouse-face-prop 'mouse-face
-      "Property used for highlighting mouse regions."))
-
-  (cond
-   ((string-match "XEmacs\\|Lucid" emacs-version)
-    (gnus-xmas-define))
-
-   ((or (not (boundp 'emacs-minor-version))
-	(and (< emacs-major-version 20)
-	     (< emacs-minor-version 30)))
-    ;; Remove the `intangible' prop.
-    (let ((props (and (boundp 'gnus-hidden-properties)
-		      gnus-hidden-properties)))
-      (while (and props (not (eq (car (cdr props)) 'intangible)))
-	(setq props (cdr props)))
-      (when props
-	(setcdr props (cdr (cdr (cdr props))))))
-    (unless (fboundp 'buffer-substring-no-properties)
-      (defun buffer-substring-no-properties (beg end)
-	(format "%s" (buffer-substring beg end)))))
-
-   ((boundp 'MULE)
-    (provide 'gnusutil))))
+      "Property used for highlighting mouse regions.")))
 
 (eval-and-compile
   (cond
@@ -120,24 +73,19 @@
 				   set-face-background x-popup-menu)))
       (while funcs
 	(unless (fboundp (car funcs))
-	  (fset (car funcs) 'gnus-dummy-func))
-	(setq funcs (cdr funcs))))))
-  (unless (fboundp 'file-regular-p)
-    (defun file-regular-p (file)
-      (and (not (file-directory-p file))
-	   (not (file-symlink-p file))
-	   (file-exists-p file))))
-  (unless (fboundp 'face-list)
-    (defun face-list (&rest args))))
+	  (defalias (car funcs) 'gnus-dummy-func))
+	(setq funcs (cdr funcs)))))))
 
 (eval-and-compile
   (let ((case-fold-search t))
     (cond
-     ((string-match "windows-nt\\|os/2\\|emx" (symbol-name system-type))
+     ((string-match "windows-nt\\|os/2\\|emx\\|cygwin32"
+		    (symbol-name system-type))
       (setq nnheader-file-name-translation-alist
 	    (append nnheader-file-name-translation-alist
-		    '((?: . ?_)
-		      (?+ . ?-))))))))
+		    (mapcar (lambda (c) (cons c ?_))
+			    '(?: ?* ?\" ?< ?> ??))
+		    '((?+ . ?-))))))))
 
 (defvar gnus-tmp-unread)
 (defvar gnus-tmp-replied)
@@ -151,38 +99,33 @@
 
 (defun gnus-ems-redefine ()
   (cond
-   ((string-match "XEmacs\\|Lucid" emacs-version)
+   (gnus-xemacs
     (gnus-xmas-redefine))
 
    ((featurep 'mule)
     ;; Mule and new Emacs definitions
 
     ;; [Note] Now there are three kinds of mule implementations,
-    ;; original MULE, XEmacs/mule and beta version of Emacs including
-    ;; some mule features. Unfortunately these API are different. In
+    ;; original MULE, XEmacs/mule and Emacs 20+ including
+    ;; MULE features.  Unfortunately these API are different.  In
     ;; particular, Emacs (including original MULE) and XEmacs are
-    ;; quite different.
+    ;; quite different.  However, this version of Gnus doesn't support
+    ;; anything other than XEmacs 20+ and Emacs 20.3+.
+
     ;; Predicates to check are following:
     ;; (boundp 'MULE) is t only if MULE (original; anything older than
     ;;                     Mule 2.3) is running.
     ;; (featurep 'mule) is t when every mule variants are running.
 
-    ;; These implementations may be able to share between original
-    ;; MULE and beta version of new Emacs. In addition, it is able to
-    ;; detect XEmacs/mule by (featurep 'mule) and to check variable
-    ;; `emacs-version'. In this case, implementation for XEmacs/mule
-    ;; may be able to share between XEmacs and XEmacs/mule.
-
-    (defalias 'gnus-truncate-string 'truncate-string)
+    ;; It is possible to detect XEmacs/mule by (featurep 'mule) and
+    ;; checking `emacs-version'.  In this case, the implementation for
+    ;; XEmacs/mule may be shareable between XEmacs and XEmacs/mule.
 
     (defvar gnus-summary-display-table nil
       "Display table used in summary mode buffers.")
-    (fset 'gnus-cite-add-face 'gnus-mule-cite-add-face)
-    (fset 'gnus-max-width-function 'gnus-mule-max-width-function)
-    (fset 'gnus-summary-set-display-table (lambda ()))
-    (fset 'gnus-encode-coding-string 'encode-coding-string)
-    (fset 'gnus-decode-coding-string 'decode-coding-string)
-    
+    (defalias 'gnus-max-width-function 'gnus-mule-max-width-function)
+    (defalias 'gnus-summary-set-display-table (lambda ()))
+
     (when (boundp 'gnus-check-before-posting)
       (setq gnus-check-before-posting
 	    (delq 'long-lines
@@ -199,13 +142,12 @@
 	  (format "%4d: %-20s"
 		  gnus-tmp-lines
 		  (if (> (length gnus-tmp-name) 20)
-		      (truncate-string gnus-tmp-name 20)
+		      (truncate-string-to-width gnus-tmp-name 20)
 		    gnus-tmp-name))
 	  gnus-tmp-closing-bracket)
 	 (point))
        gnus-mouse-face-prop gnus-mouse-face)
-      (insert " " gnus-tmp-subject-or-nil "\n"))
-    )))
+      (insert " " gnus-tmp-subject-or-nil "\n")))))
 
 (defun gnus-region-active-p ()
   "Say whether the region is active."
@@ -214,9 +156,9 @@
        (boundp 'mark-active)
        mark-active))
 
-(defun gnus-add-minor-mode (mode name map)
-  (if (fboundp 'add-minor-mode)
-      (add-minor-mode mode name map)
+(if (fboundp 'add-minor-mode)
+    (defalias 'gnus-add-minor-mode 'add-minor-mode)
+  (defun gnus-add-minor-mode (mode name map)
     (set (make-local-variable mode) t)
     (unless (assq mode minor-mode-alist)
       (push `(,mode ,name) minor-mode-alist))
@@ -234,23 +176,22 @@
 	(erase-buffer)
 	(when (and dir
 		   (file-exists-p (setq file (concat dir "x-splash"))))
-	  (nnheader-temp-write nil
+	  (with-temp-buffer
 	    (insert-file-contents file)
 	    (goto-char (point-min))
 	    (ignore-errors
 	      (setq pixmap (read (current-buffer))))))
 	(when pixmap
-	  (erase-buffer)
 	  (unless (facep 'gnus-splash)
 	    (make-face 'gnus-splash))
 	  (setq height (/ (car pixmap) (frame-char-height))
 		width (/ (cadr pixmap) (frame-char-width)))
-	  (set-face-foreground 'gnus-splash "ForestGreen")
+	  (set-face-foreground 'gnus-splash "Brown")
 	  (set-face-stipple 'gnus-splash pixmap)
 	  (insert-char ?\n (* (/ (window-height) 2 height) height))
 	  (setq i height)
 	  (while (> i 0)
-	    (insert-char ?  (* (+ (/ (window-width) 2 width) 1) width))
+	    (insert-char ?  (* (/ (window-width) 2 width) width))
 	    (setq beg (point))
 	    (insert-char ?  width)
 	    (set-text-properties beg (point) '(face gnus-splash))
@@ -259,15 +200,56 @@
 	  (goto-char (point-min))
 	  (sit-for 0))))))
 
-(if (fboundp 'split-string)
-    (fset 'gnus-split-string 'split-string)
-  (defun gnus-split-string (string pattern)
-    "Return a list of substrings of STRING which are separated by PATTERN."
-    (let (parts (start 0))
-      (while (string-match pattern string start)
-	(setq parts (cons (substring string start (match-beginning 0)) parts)
-	      start (match-end 0)))
-      (nreverse (cons (substring string start) parts)))))
+(defvar gnus-article-xface-ring-internal nil
+  "Cache for face data.")
+
+;; Worth customizing?
+(defvar gnus-article-xface-ring-size 6
+  "Length of the ring used for `gnus-article-xface-ring-internal'.")
+
+(defun gnus-article-display-xface (beg end)
+  "Display an XFace header from between BEG and END in the current article.
+This requires support images in your Emacs and the external programs
+`uncompface', `icontopbm' and `ppmtoxbm'.  On a GNU/Linux system these
+might be in packages with names like `compface' or `faces-xface' and
+`netpbm' or `libgr-progs', for instance.
+
+This function is for Emacs 21+.  See `gnus-xmas-article-display-xface'
+for XEmacs."
+  ;; It might be worth converting uncompface's output in Lisp.
+
+  (unless gnus-article-xface-ring-internal ; Only load ring when needed.
+    (setq gnus-article-xface-ring-internal
+	  (make-ring gnus-article-xface-ring-size)))
+  (save-excursion
+    (let* ((cur (current-buffer))
+	   (data (buffer-substring beg end))
+	   (image (cdr-safe (assoc data (ring-elements
+					 gnus-article-xface-ring-internal)))))
+      (when (if (fboundp 'display-graphic-p)
+		(display-graphic-p))
+	(unless image
+	  (let ((coding-system-for-read 'binary)
+		(coding-system-for-write 'binary))
+	    (with-temp-buffer
+	      (insert data)
+	      (and (eq 0 (call-process-region (point-min) (point-max)
+					      "uncompface"
+					      'delete '(t nil)))
+		   (goto-char (point-min))
+		   (progn (insert "/* Width=48, Height=48 */\n") t)
+		   (eq 0 (call-process-region (point-min) (point-max)
+					      "icontopbm"
+					      'delete '(t nil)))
+		   (eq 0 (call-process-region (point-min) (point-max)
+					      "pbmtoxbm"
+					      'delete '(t nil)))
+		   (setq image (create-image (buffer-string) 'xbm t)))))
+	  (ring-insert gnus-article-xface-ring-internal (cons data image))))
+      (when image
+	(goto-char (point-min))
+	(re-search-forward "^From:" nil 'move)
+	(insert-image image)))))
 
 (provide 'gnus-ems)
 
